C $Header: /u/gcmpack/models/MITgcmUV/model/src/ini_uvel.F,v 1.7 1998/12/09 16:11:53 adcroft Exp $

#include "CPP_OPTIONS.h"

CStartOfInterface
      SUBROUTINE INI_UVEL( myThid )
C     /==========================================================\
C     | SUBROUTINE INI_UVEL                                      |
C     | o Set model initial zonal velocity field.                |
C     |==========================================================|
C     | There are several options for setting the initial        |
C     | zonal velocity field.                                    |
C     |  1. Inline code                                          |
C     |  2. Three-dimensional data from a file. For example from |
C     |     a checkpoint file from a previous integration.       |
C     | In addition to setting the velocity field we also        |
C     | set the initial velocity tendency term here.             |
C     \==========================================================/
      IMPLICIT NONE

C     === Global variables ===
#include "SIZE.h"
#include "EEPARAMS.h"
#include "PARAMS.h"
#include "GRID.h"
#include "DYNVARS.h"

C     == Routine arguments ==
C     myThid -  Number of this instance of INI_UVEL 
      INTEGER myThid
CEndOfInterface

C     == Local variables ==
C     iC, jC - Center of domain
C     iD, jD - Disitance from domain center.
C     rad    - Radius of initial patch
C     rD     - Radial displacement of point I,J
C     iG, jG - Global coordinate index
C     bi,bj  - Loop counters
C     I,J,K
      INTEGER iC, jC, iD, jD
      INTEGER iG, jG
      INTEGER bi, bj
      INTEGER  I,  J, K
      REAL rad, rD

C--   Initialise velocity field to zero
      DO bj = myByLo(myThid), myByHi(myThid)
       DO bi = myBxLo(myThid), myBxHi(myThid)
        DO K=1,Nr
         DO J=1,sNy
          DO I=1,sNx
           uVel (I,J,K,bi,bj) = 0. _d 0
#ifdef INCLUDE_CD_CODE
           uVeld(I,J,K,bi,bj) = 0. _d 0
           uNM1 (I,J,K,bi,bj) = 0. _d 0
#endif
          ENDDO
         ENDDO
        ENDDO
       ENDDO
      ENDDO
C     Set initial tendency terms
      DO bj = myByLo(myThid), myByHi(myThid)
       DO bi = myBxLo(myThid), myBxHi(myThid)
        DO K=1,Nr
         DO J=1,sNy
          DO I=1,sNx
           gu   (I,J,K,bi,bj) = 0. _d 0
           guNM1(I,J,K,bi,bj) = 0. _d 0
#ifdef INCLUDE_CD_CODE
           guCD (I,J,K,bi,bj) = 0. _d 0
#endif
          ENDDO
         ENDDO
        ENDDO
       ENDDO
      ENDDO
C
      _EXCH_XYZ_R8(uVel  , myThid )
      _EXCH_XYZ_R8(gu    , myThid )
      _EXCH_XYZ_R8(guNM1 , myThid )
#ifdef INCLUDE_CD_CODE
      _EXCH_XYZ_R8(uVeld , myThid )
      _EXCH_XYZ_R8(uNM1  , myThid )
      _EXCH_XYZ_R8(guCD  , myThid )
#endif
      RETURN
      END
